@@ -11,6 +11,7 @@
 #include <arpa/inet.h>
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <gconf/gconf-client.h>
 
 #include "contactinfos.h"
 #include "client-contactinfos-dbus.h"
@@ -45,6 +46,7 @@ struct UICStruct {
 	gboolean contactInfosAvailable;
 	gboolean dial;
 	gboolean gsm;
+	gboolean transformPlus;
 };
 typedef struct UICStruct UIComponents;
 
@@ -67,8 +69,15 @@ static void sendSMS (gchar *number, gchar *text);
 /* D-BUS service definitions */
 #define APPLICATION_DBUS_SERVICE "phonelink"
 
+#define GCONF_TRANSFORM_PLUS_KEY "/apps/phonelink/TransformPlusIntoDoubleZero"
 
 static void  quit_event( UIComponents *uic, guint callback_action, GtkWidget *menu_item	) {
+	GConfClient *gconf_client = NULL;
+
+	gconf_client = gconf_client_get_default ();
+	gconf_client_set_bool(gconf_client, GCONF_TRANSFORM_PLUS_KEY, uic->transformPlus, NULL);
+	gconf_client_suggest_sync (gconf_client, NULL);
+	g_object_unref (gconf_client);
 
         gn_lib_phoneprofile_free(&state);
         gn_lib_library_free();
@@ -162,6 +171,48 @@ void oneResultSignal_cb(
 
 }
 
+void on_menu_quit(GtkMenuItem * menuitem, UIComponents *uic) {
+	quit_event( uic, 0, NULL);
+}
+
+void on_menu_transform(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
+	uic->transformPlus = !(uic->transformPlus);
+}
+
+GtkMenu *create_menus(UIComponents *uic) {
+	GtkWidget *menuBar;
+	GtkWidget *menuGroup;
+	GtkWidget *menuItem;
+	GtkWidget *image;
+	
+	menuBar = gtk_menu_new ();
+	
+	menuGroup = gtk_menu_new();
+	menuItem = gtk_menu_item_new_with_label (_("File"));
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuItem), menuGroup);
+	gtk_menu_append(menuBar, menuItem);
+	
+	menuItem = gtk_image_menu_item_new_with_label (_("Quit"));
+	image = gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem), image);
+	g_signal_connect (G_OBJECT (menuItem), "activate", G_CALLBACK (on_menu_quit), (gpointer) uic);
+	gtk_menu_append(menuGroup, menuItem);
+	
+	menuGroup = gtk_menu_new();
+	menuItem = gtk_menu_item_new_with_label (_("Edit"));
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuItem), menuGroup);
+	gtk_menu_append(menuBar, menuItem);
+	
+	menuItem = gtk_check_menu_item_new_with_label (_("Transform + into 00"));
+	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_transform), (gpointer) uic);
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuItem), uic->transformPlus);
+	gtk_menu_append(menuGroup, menuItem);
+	
+	return GTK_MENU(menuBar);
+}
+
+
+
 void getDBusNumbers(UIComponents *uic, gboolean dial, gboolean gsm) {
 	DBusGConnection *connection;
 	GError *error = NULL;
@@ -269,7 +320,7 @@ static gboolean delete_event( GtkWidget *widget, GdkEvent *event, gpointer data
 	return TRUE;
 }
 
-static gchar * normalizeNumber( gchar *number) {
+static gchar * normalizeNumber( gchar *number, gboolean transformPlus) {
 
 	if (!number) {
 		return number;
@@ -279,7 +330,7 @@ static gchar * normalizeNumber( gchar *number) {
 	guint i = 0;
 	guint j = 0;
 	g_strstrip(number);
-	if (number[0] == '+') {
+	if (transformPlus && number[0] == '+') {
 		normalizedNumber[0] = '0';
 		normalizedNumber[1] = '0';
 		j = 2;
@@ -296,9 +347,9 @@ static gchar * normalizeNumber( gchar *number) {
 }
 
 
-static gchar * normalizeNumber4Sip( gchar *number ) {
+static gchar * normalizeNumber4Sip( gchar *number, gboolean transformPlus ) {
 
-	gchar * num = normalizeNumber(number);
+	gchar * num = normalizeNumber(number, transformPlus);
 	gchar * res = g_strconcat("sip:", num, NULL); /*, "@freephonie.net" */
 	g_free(num);
 	return res;
@@ -386,7 +437,7 @@ void dialNumber(UIComponents * uic, gchar *number) {
 	gchar *text;
 	
 	if (number && number[0] != '\0') {
-		normalizedNumber = normalizeNumber(number);
+		normalizedNumber = normalizeNumber(number, uic->transformPlus);
 		if (normalizedNumber == NULL || normalizedNumber[0] == '\0') {
 			text = g_strdup_printf("Number %s is not Valid !\n", number);
 			hildon_banner_show_information(GTK_WIDGET(gtk_widget_get_toplevel(uic->searchEntry)), GTK_STOCK_DIALOG_ERROR, text);
@@ -402,7 +453,7 @@ void dialNumber(UIComponents * uic, gchar *number) {
 		if (uic->gsm == TRUE) {
 			ret = dialGsm(normalizedNumber, &text);
 		} else {
-			sipNormalizedNumber = normalizeNumber4Sip(normalizedNumber);
+			sipNormalizedNumber = normalizeNumber4Sip(normalizedNumber, uic->transformPlus);
 			ret = dialSip(sipNormalizedNumber, &text, uic);
 			g_free(sipNormalizedNumber);
 		}
@@ -576,7 +627,7 @@ static void sendSMS_cb (GtkButton *widget, UIComponents *uic) {
 		getDBusNumbers(uic, FALSE, TRUE);
 	} else {
 		/* dial the number from the searchEntry */
-		normalizedNumber=normalizeNumber((gchar *) gtk_entry_get_text(GTK_ENTRY(uic->searchEntry)));
+		normalizedNumber=normalizeNumber((gchar *) gtk_entry_get_text(GTK_ENTRY(uic->searchEntry)), uic->transformPlus);
 		text = getSMSText(uic);
 		if (text) {
 			showMessageSendSMS(GTK_WIDGET(widget), normalizedNumber);
@@ -668,7 +719,7 @@ gboolean sendSMSToIter (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *ite
 	text=getSMSText(uic);
 			
 	gtk_tree_model_get(model, iter, NUMBER_COLUMN, &number, -1);
-	normalizedNumber = normalizeNumber(number);
+	normalizedNumber = normalizeNumber(number, uic->transformPlus);
 	showMessageSendSMS(GTK_WIDGET(uic->searchEntry), normalizedNumber);
 	sendSMS (normalizedNumber, text);
 	g_free(normalizedNumber);
@@ -738,6 +789,7 @@ int main( int argc, char *argv[] ) {
 	GtkWidget *scrolled_window;
 	GtkWidget *smsTextView;
 	GtkTextBuffer *buffer;
+	GConfClient *gconf_client = NULL;
 	
 	HildonProgram *app;
 	HildonWindow *appview;
@@ -758,7 +810,14 @@ int main( int argc, char *argv[] ) {
 
 	g_type_init ();
 
-	/* Gnokii : read the config */
+	/* Read GConf Info */
+	gconf_client = gconf_client_get_default ();
+	uic->transformPlus = gconf_client_get_bool(gconf_client, GCONF_TRANSFORM_PLUS_KEY, NULL);
+	g_object_unref (gconf_client);
+
+	hildon_window_set_menu (appview, create_menus (uic));
+
+/* Gnokii : read the config */
 /*	if (gn_cfg_read(&bindir) < 0) {
 		 hildon_banner_show_information(GTK_WIDGET(appview), NULL, "gnokii rc file reading problem\n");
 	} else {
